@@ -7,11 +7,13 @@ use Path::Tiny;
 use HTTP::Date;
 use Mojo::UserAgent;
 use App::txtnix::Tweet;
+use App::txtnix::Source;
 use App::txtnix::Cache;
+use App::txtnix::Registry;
 use IO::Pager;
 use Mojo::ByteStream 'b';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has 'ua' => sub { shift->_build_ua };
 has cache => sub { App::txtnix::Cache->new( cache_dir => shift->cache_dir ) };
@@ -33,35 +35,29 @@ has nick              => sub { $ENV{USER} };
 has since             => sub { 0 };
 has until             => sub { time };
 
-has [qw( twturl pre_tweet_hook post_tweet_hook config force )];
+has [qw( twturl pre_tweet_hook post_tweet_hook config force registry )];
 
 sub new {
     my ( $class, @args ) = @_;
     my $args = ref $args[0] ? $args[0] : {@args};
 
-    $args->{use_cache} = delete $args->{cache}
-      if exists $args->{cache};
-
-    $args->{use_pager} = delete $args->{pager}
-      if exists $args->{pager};
+    for (qw(cache pager)) {
+        $args->{"use_$_"} = delete $args->{$_} if exists $args->{$_};
+    }
 
     $args->{config} =
       path( $args->{config} || '~/.config/twtxt/config' );
 
-    $args->{since} = $class->to_epoch( $args->{since} )
-      if exists $args->{since};
-    $args->{until} = $class->to_epoch( $args->{until} )
-      if exists $args->{until};
-
-    if ( exists $args->{ascending} and $args->{ascending} ) {
-        $args->{sorting} = 'ascending';
+    for (qw(since until)) {
+        $args->{$_} = $class->to_epoch( $args->{$_} ) if exists $args->{$_};
     }
-    if ( exists $args->{descending} and $args->{descending} ) {
-        $args->{sorting} = 'descending';
+
+    for (qw(ascending descending )) {
+        $args->{sorting} = $_ if exists $args->{$_} && $args->{$_};
     }
 
     if ( $args->{config}->exists ) {
-        my $config = $class->read_file( $args->{config} );
+        my $config = $class->read_config( $args->{config} );
         if ( $config->{twtxt} ) {
             $args = { %{ $config->{twtxt} }, %$args };
         }
@@ -92,13 +88,13 @@ sub _build_ua {
     return $ua;
 }
 
-sub write_file {
+sub write_config {
     my ( $self, $config ) = @_;
     $config->write( $self->config, 'utf8' );
     return;
 }
 
-sub read_file {
+sub read_config {
     my ( $self, $file ) = @_;
     my $config =
       Config::Tiny->read( $file || $self->config->stringify, 'utf8' );
@@ -117,9 +113,9 @@ sub sync {
         $self->config->parent->mkpath;
         $self->config->touch;
     }
-    my $config = $self->read_file;
+    my $config = $self->read_config;
     $config->{following} = $self->following;
-    $self->write_file($config);
+    $self->write_config($config);
     return;
 }
 
@@ -135,31 +131,26 @@ sub get_tweets {
             return;
         }
     }
-    Mojo::IOLoop->delay(
-        sub {
-            my $delay = shift;
-            while ( my ( $user, $url ) = each %{$following} ) {
-                my ( $cache, $params ) = ( undef, {} );
-                if ( $self->use_cache ) {
-                    $cache = $self->cache->get($url);
-                    if ($cache) {
-                        $params =
-                          { "If-Modified-Since" => $cache->{last_modified} };
-                    }
-                }
-                $delay->pass( $user, $cache );
-                $self->ua->get( $url => $params => $delay->begin );
+    my $delay = Mojo::IOLoop->delay;
+
+    while ( my ( $user, $url ) = each %{$following} ) {
+        my ( $cache, $params ) = ( undef, {} );
+        if ( $self->use_cache ) {
+            $cache = $self->cache->get($url);
+            if ($cache) {
+                $params = { "If-Modified-Since" => $cache->{last_modified} };
             }
-        },
-        sub {
-            my ( $delay, @results ) = @_;
-            while ( my ( $user, $cache, $tx ) = splice( @results, 0, 3 ) ) {
+        }
+        my $end = $delay->begin;
+        $self->ua->get(
+            $url => $params => sub {
+                my ( $ua, $tx ) = @_;
 
                 if ( my $res = $tx->success ) {
 
                     $self->check_for_moved_url( $tx, $user );
 
-                    my $body = $res->body;
+                    my $body = b( $res->body )->decode;
                     if ( $res->code == 304 && $cache ) {
                         $body = $cache->{body};
                     }
@@ -173,10 +164,13 @@ sub get_tweets {
                         && $res->code == 200
                         && $res->headers->last_modified )
                     {
-                        $self->cache->set( $self->following->{$user},
-                            $res->headers->last_modified, $body );
+                        $self->cache->set( $url, $res->headers->last_modified,
+                            $body );
                     }
-                    push @tweets, $self->parse_twtfile( $user, $body );
+                    my $source =
+                      App::txtnix::Source->new( url => $url, nick => $user );
+                    push @tweets, $self->parse_twtfile( $source, $body );
+
                 }
                 else {
                     my $err = $tx->error;
@@ -187,6 +181,7 @@ sub get_tweets {
                         : "Connection error: $err->{message}"
                       ) . "\n";
                     if (   $tx->res
+                        && $tx->res->code
                         && $tx->res->code == 410
                         && $self->rewrite_urls )
                     {
@@ -194,13 +189,44 @@ sub get_tweets {
                         delete $self->following->{$user};
                     }
                 }
+                $end->();
             }
-        }
-    )->wait;
+        );
+    }
+
+    if ( !$who && $self->registry && $self->twturl ) {
+        my $end = $delay->begin;
+        my $registry =
+          App::txtnix::Registry->new( url => $self->registry, ua => $self->ua );
+        my @mentions = $registry->get_mentions(
+            $self->twturl => sub {
+                my (@results) = @_;
+                for my $result (@results) {
+                    my ( $nick, $url ) =
+                      $result->[0] =~ /\@<(?:(\w+) )?([^>]+)>/;
+                    my $source =
+                      App::txtnix::Source->new( url => $url, nick => $nick );
+                    push @tweets,
+                      App::txtnix::Tweet->new(
+                        timestamp => $self->to_epoch( $result->[1] ),
+                        text      => $result->[2],
+                        source    => $source,
+                      );
+                }
+                $end->();
+            }
+        );
+    }
+
+    $delay->wait;
 
     if ( not defined $who and $self->twtfile->exists ) {
+        my $source = App::txtnix::Source->new(
+            file => $self->twtfile,
+            nick => $self->nick,
+        );
         push @tweets,
-          $self->parse_twtfile( $self->nick, $self->twtfile->slurp_utf8 );
+          $self->parse_twtfile( $source, $self->twtfile->slurp_utf8 );
     }
 
     $self->sync;
@@ -218,6 +244,14 @@ sub filter_tweets {
       grep { $_->timestamp >= $self->since && $_->timestamp <= $self->until }
       @tweets;
 
+    my %seen_tweets;
+
+    for my $tweet (@tweets) {
+        $seen_tweets{ $tweet->md5_hash } = $tweet;
+    }
+
+    @tweets = values %seen_tweets;
+
     @tweets = sort {
             $self->sorting eq 'descending'
           ? $b->timestamp <=> $a->timestamp
@@ -245,18 +279,17 @@ sub check_for_moved_url {
 }
 
 sub parse_twtfile {
-    my ( $self, $user, $string ) = @_;
+    my ( $self, $source, $string ) = @_;
     my @tweets;
     for my $line ( split( /\n/, $string ) ) {
         my ( $time, $text ) = split( /\t/, $line, 2 );
         next if not defined $text;
-        $text = b($text)->decode;
         $text =~ s/\P{XPosixPrint}//g;
         $time = $self->to_epoch($time);
         if ( $time and $text ) {
             push @tweets,
               App::txtnix::Tweet->new(
-                user      => $user,
+                source    => $source,
                 timestamp => $time,
                 text      => $text,
               );
@@ -275,15 +308,39 @@ sub display_tweets {
         $fh = \*STDOUT;
     }
     for my $tweet (@tweets) {
-        my $text = $tweet->text;
-        $text = $self->collapse_mentions($text);
-        printf {$fh} "%s %s: %s\n",
-          $tweet->strftime( $self->time_format ),
-          $tweet->user, b($text)->encode;
+        my $time = $tweet->strftime( $self->time_format );
+        my $text = $self->collapse_mentions( $tweet->text || '' );
+
+        my $nick;
+        if ( $tweet->source->file ) {
+            $nick = $tweet->source->nick;
+        }
+        elsif ( $tweet->source->url ) {
+            if ( !( $nick = $self->url_to_nick( $tweet->source->url ) ) ) {
+                if ( $tweet->source->nick ) {
+                    $nick = '@<'
+                      . $tweet->source->nick . ' '
+                      . $tweet->source->url . '>';
+                }
+                else {
+                    $nick = '@<' . $tweet->source->url . '>';
+                }
+            }
+        }
+        my $line = "$time $nick: $text\n";
+
+        print {$fh} b($line)->encode,;
     }
     return;
 }
 
+sub url_to_nick {
+    my ( $self, $url ) = @_;
+    my $known_users = $self->known_users;
+    my %urls = map { $known_users->{$_} => $_ } keys %{$known_users};
+    return $urls{$url};
+}
+
 sub collapse_mentions {
     my ( $self, $text ) = @_;
     $text =~ s/\@<(?:(\w+) )?([^>]+)>/$self->collapse_mention($1,$2)/ge;
@@ -292,14 +349,8 @@ sub collapse_mentions {
 
 sub collapse_mention {
     my ( $self, $user, $url ) = @_;
-    my $known_users = $self->known_users;
-    my %urls = map { $known_users->{$_} => $_ } keys %{$known_users};
-    if ( $urls{$url} ) {
-        return "\@$urls{$url}";
-    }
-    else {
-        return "\@<$user $url>";
-    }
+    my $nick = $self->url_to_nick($url);
+    return $nick ? "\@$nick" : $user ? "\@<$user $url>" : "\@<$url>";
 }
 
 sub known_users {
