@@ -1,21 +1,17 @@
 package App::txtnix::Cache;
-use strict;
-use warnings;
-use Moo;
+use Mojo::Base -base;
 use Mojo::ByteStream 'b';
 use Path::Tiny;
 use Mojo::JSON qw(encode_json decode_json);
 
-has cache_dir => ( is => 'lazy', coerce => \&to_path );
+has cache_dir => sub { path('~/.cache/txtnix/') };
 
-sub to_path {
-    ref $_[0] eq 'Path::Tiny' ? $_[0] : path( $_[0] );
-}
-
-sub _build_cache_dir {
-    my $dir = path('~/.cache/txtnix/');
-    $dir->mkpath if not $dir->exists;
-    return $dir;
+sub new {
+    my $class = shift;
+    my $self = bless @_ ? @_ > 1 ? {@_} : { %{ $_[0] } } : {},
+      ref $class || $class;
+    $self->cache_dir->mkpath if not $self->cache_dir->exists;
+    return $self;
 }
 
 sub get {
