@@ -1,9 +1,10 @@
 package App::txtnix::Tweet;
 use Mojo::Base -base;
 use HTTP::Date 'str2time';
+use Mojo::ByteStream 'b';
 use POSIX ();
 
-has [ 'user', 'text' ];
+has [qw(source text)];
 has timestamp => sub { time };
 
 sub strftime {
@@ -16,4 +17,9 @@ sub to_string {
     return $self->strftime('%FT%T%z') . "\t" . $self->text;
 }
 
+sub md5_hash {
+    my $self = shift;
+    return b( $self->timestamp . $self->text )->encode->md5_sum;
+}
+
 1;
